// Copyright (c) by respective owners including Yahoo!, Microsoft, and
// individual contributors. All rights reserved. Released under a BSD (revised)
// license as described in the file LICENSE.

#pragma once

#include "vw/core/multi_ex.h"
#include "vw/core/vw_fwd.h"

namespace VW
{
namespace LEARNER
{
class learner;
}  // namespace LEARNER
}  // namespace VW
